<?php
add_action('init', 'my_custom_init_info_box');
function my_custom_init_info_box() 
{
  $labels = array(
    'name' => _x('Info Box', 'post type general name'),
    'singular_name' => _x('Info Box', 'post type singular name'),
    'add_new' => _x('Add Info Box', 'info-box'),
    'add_new_item' => __('Add New Info Box'),
    'edit_item' => __('Edit '),
    'new_item' => __('New Info Box'),
    'view_item' => __('View Info Box'),
    'search_items' => __('Search Info Boxes'),
    'not_found' =>  __('No Info Boxes found'),
    'not_found_in_trash' => __('No Info Boxes found in Trash'), 
    'parent_item_colon' => ''
  );
  $args = array(
    'labels' => $labels,
    'public' => true,
    'publicly_queryable' => true,
    'show_ui' => true, 
    'query_var' => true,
    'rewrite' => true,
    'capability_type' => 'post',
    'hierarchical' => false,
    'menu_position' => null,
    'supports' => array('title','editor','author','thumbnail','excerpt','comments')
  ); 
  register_post_type('info-box',$args);
	
	/***************************************************************/
	/*  Post Type Custom Meta, here used to add a category */
	
	register_taxonomy( 'info-box-category', 'info-box', array( 'hierarchical' => true, 'label' => 'Categories', 'query_var' => true, 'rewrite' => true ) );  
}

//add filter to insure the text info_box, or info_box, is displayed when user updates a info_box 
add_filter('post_updated_messages', 'info_box_updated_messages');
function info_box_updated_messages( $messages ) {

  $messages['info-box'] = array(
    0 => '', // Unused. Messages start at index 1.
    1 => sprintf( __('Info updated. <a href="%s">View Info Box</a>'), esc_url( get_permalink($post_ID) ) ),
    2 => __('Custom field updated.'),
    3 => __('Custom field deleted.'),
    4 => __('Updated.'),
    /* translators: %s: date and time of the revision */
    5 => isset($_GET['revision']) ? sprintf( __('Restored to revision from %s'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
    6 => sprintf( __('Published. <a href="%s">View</a>'), esc_url( get_permalink($post_ID) ) ),
    7 => __('Product saved.'),
    8 => sprintf( __('Submitted. <a target="_blank" href="%s">Preview</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
    9 => sprintf( __('Scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview</a>'),
      // translators: Publish box date format, see http://php.net/date
      date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
    10 => sprintf( __('Draft updated. <a target="_blank" href="%s">Preview</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
  );

  return $messages;
}
/***************************************************************/
/* Info Boxes Post Type Custom Meta, here used to add a category */

function info_box_links() {
	global $post, $obox_meta;
	$link = get_post_meta($post->ID,"info_box_link",true);
?>
	<p><input type="text" class="widefat" name="info_box_link" value="<?php echo $link; ?>" /></p>
    <p><em>Redirect the user to a custom location.</em></p>
<?php
}
function insert_info_box_links($pID) {
	global $category_added;
	$i = 0;
	if(!isset($category_added)) :
		add_post_meta($pID,"info_box_link",$_POST["info_box_link"],true) or update_post_meta($pID,"info_box_link",$_POST["info_box_link"]);
		$meta_added = 1;
	endif;
}

function add_custom_info_box_link() {
	add_meta_box('obox-custom-type-cats','Custom Link','info_box_links','info-box','side');
	add_meta_box('obox-custom-type-cats','Custom Link','info_box_links','quotes','side');
	add_meta_box('obox-meta-box',$GLOBALS['themename'].' Options','create_info_meta_box_ui','info-box','normal','high');
}

add_action('admin_menu', 'add_custom_info_box_link');
add_action('save_post', 'insert_info_box_links');

/************************************************************************/
/* Info Boxes Post Type Custom archives page, here used to add a category */

add_new_info_box_rules();
function add_new_info_box_rules(){
	global $wp_rewrite, $info_box_permalink;
	$rewrite_rules = $wp_rewrite->generate_rewrite_rules('info-box/');
	$rewrite_rules['info-box/?$'] = 'index.php?paged=1';

	foreach($rewrite_rules as $regex => $redirect)
	{
		if(strpos($redirect, 'attachment=') === false)
			{
				$redirect .= '&post_type=info-box';
			}
		if(0 < preg_match_all('@\$([0-9])@', $redirect, $matches))
			{
				for($i = 0; $i < count($matches[0]); $i++)
				{
					$redirect = str_replace($matches[0][$i], '$matches['.$matches[1][$i].']', $redirect);
				}
			}
		$wp_rewrite->add_rule($regex, $redirect, 'top');
	}
	$info_box_permalink = $redirect;
}

?>